@@ -13,69 +13,104 @@ import (
 	"github.com/cli/cli/v2/api"
 	fd "github.com/cli/cli/v2/internal/featuredetection"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	o "github.com/cli/cli/v2/pkg/option"
 	"github.com/cli/cli/v2/pkg/set"
 	"golang.org/x/sync/errgroup"
 )
 
-// IssueFromArgWithFields loads an issue or pull request with the specified fields. If some of the fields
-// could not be fetched by GraphQL, this returns a non-nil issue and a *PartialLoadError.
-func IssueFromArgWithFields(httpClient *http.Client, baseRepoFn func() (ghrepo.Interface, error), arg string, fields []string) (*api.Issue, ghrepo.Interface, error) {
-	issueNumber, baseRepo, err := IssueNumberAndRepoFromArg(arg)
-	if err != nil {
-		return nil, nil, err
-	}
+var issueURLRE = regexp.MustCompile(`^/([^/]+)/([^/]+)/(?:issues|pull)/(\d+)`)
 
-	if baseRepo == nil {
-		var err error
-		if baseRepo, err = baseRepoFn(); err != nil {
-			return nil, nil, err
-		}
-	}
+func ParseIssuesFromArgs(args []string) ([]int, o.Option[ghrepo.Interface], error) {
+	var repo o.Option[ghrepo.Interface]
+	issueNumbers := make([]int, len(args))
 
-	issue, err := findIssueOrPR(httpClient, baseRepo, issueNumber, fields)
-	return issue, baseRepo, err
-}
-
-// IssuesFromArgsWithFields loads 1 or more issues or pull requests with the specified fields. If some of the fields
-// could not be fetched by GraphQL, this returns non-nil issues and a *PartialLoadError.
-func IssuesFromArgsWithFields(httpClient *http.Client, baseRepoFn func() (ghrepo.Interface, error), args []string, fields []string) ([]*api.Issue, ghrepo.Interface, error) {
-	var issuesRepo ghrepo.Interface
-	issueNumbers := make([]int, 0, len(args))
-
-	for _, arg := range args {
-		issueNumber, baseRepo, err := IssueNumberAndRepoFromArg(arg)
+	for i, arg := range args {
+		// For each argument, parse the issue number and an optional repo
+		issueNumber, issueRepo, err := ParseIssueFromArg(arg)
 		if err != nil {
-			return nil, nil, err
+			return nil, o.None[ghrepo.Interface](), err
 		}
 
-		issueNumbers = append(issueNumbers, issueNumber)
-		if baseRepo == nil {
-			var err error
-			if baseRepo, err = baseRepoFn(); err != nil {
-				return nil, nil, err
+		// if this is our first issue repo found, then we need to set it
+		if repo.IsNone() {
+			repo = issueRepo
+		}
+
+		// if there is an issue repo returned, then we need to check if it is the same as the previous one
+		if issueRepo.IsSome() && repo.IsSome() {
+			// Unwraps are safe because we've checked for presence above
+			if !ghrepo.IsSame(repo.Unwrap(), issueRepo.Unwrap()) {
+				return nil, o.None[ghrepo.Interface](), fmt.Errorf(
+					"multiple issues must be in same repo: found %q, expected %q",
+					ghrepo.FullName(issueRepo.Unwrap()),
+					ghrepo.FullName(repo.Unwrap()),
+				)
 			}
 		}
 
-		if issuesRepo == nil {
-			issuesRepo = baseRepo
-			continue
-		}
-
-		if !ghrepo.IsSame(issuesRepo, baseRepo) {
-			return nil, nil, fmt.Errorf(
-				"multiple issues must be in same repo: found %q, expected %q",
-				ghrepo.FullName(baseRepo),
-				ghrepo.FullName(issuesRepo),
-			)
-		}
+		// add the issue number to the list
+		issueNumbers[i] = issueNumber
 	}
 
-	issuesChan := make(chan *api.Issue, len(args))
+	return issueNumbers, repo, nil
+}
+
+func ParseIssueFromArg(arg string) (int, o.Option[ghrepo.Interface], error) {
+	issueLocator := tryParseIssueFromURL(arg)
+	if issueLocator, present := issueLocator.Value(); present {
+		return issueLocator.issueNumber, o.Some(issueLocator.repo), nil
+	}
+
+	issueNumber, err := strconv.Atoi(strings.TrimPrefix(arg, "#"))
+	if err != nil {
+		return 0, o.None[ghrepo.Interface](), fmt.Errorf("invalid issue format: %q", arg)
+	}
+
+	return issueNumber, o.None[ghrepo.Interface](), nil
+}
+
+type issueLocator struct {
+	issueNumber int
+	repo        ghrepo.Interface
+}
+
+// tryParseIssueFromURL tries to parse an issue number and repo from a URL.
+func tryParseIssueFromURL(maybeURL string) o.Option[issueLocator] {
+	u, err := url.Parse(maybeURL)
+	if err != nil {
+		return o.None[issueLocator]()
+	}
+
+	if u.Scheme != "https" && u.Scheme != "http" {
+		return o.None[issueLocator]()
+	}
+
+	m := issueURLRE.FindStringSubmatch(u.Path)
+	if m == nil {
+		return o.None[issueLocator]()
+	}
+
+	repo := ghrepo.NewWithHost(m[1], m[2], u.Hostname())
+	issueNumber, _ := strconv.Atoi(m[3])
+	return o.Some(issueLocator{
+		issueNumber: issueNumber,
+		repo:        repo,
+	})
+}
+
+type PartialLoadError struct {
+	error
+}
+
+// FindIssuesOrPRs loads 1 or more issues or pull requests with the specified fields. If some of the fields
+// could not be fetched by GraphQL, this returns non-nil issues and a *PartialLoadError.
+func FindIssuesOrPRs(httpClient *http.Client, repo ghrepo.Interface, issueNumbers []int, fields []string) ([]*api.Issue, error) {
+	issuesChan := make(chan *api.Issue, len(issueNumbers))
 	g := errgroup.Group{}
 	for _, num := range issueNumbers {
 		issueNumber := num
 		g.Go(func() error {
-			issue, err := findIssueOrPR(httpClient, issuesRepo, issueNumber, fields)
+			issue, err := FindIssueOrPR(httpClient, repo, issueNumber, fields)
 			if err != nil {
 				return err
 			}
@@ -89,60 +124,18 @@ func IssuesFromArgsWithFields(httpClient *http.Client, baseRepoFn func() (ghrepo
 	close(issuesChan)
 
 	if err != nil {
-		return nil, nil, err
+		return nil, err
 	}
 
-	issues := make([]*api.Issue, 0, len(args))
+	issues := make([]*api.Issue, 0, len(issueNumbers))
 	for issue := range issuesChan {
 		issues = append(issues, issue)
 	}
 
-	return issues, issuesRepo, nil
+	return issues, nil
 }
 
-var issueURLRE = regexp.MustCompile(`^/([^/]+)/([^/]+)/(?:issues|pull)/(\d+)`)
-
-func issueMetadataFromURL(s string) (int, ghrepo.Interface) {
-	u, err := url.Parse(s)
-	if err != nil {
-		return 0, nil
-	}
-
-	if u.Scheme != "https" && u.Scheme != "http" {
-		return 0, nil
-	}
-
-	m := issueURLRE.FindStringSubmatch(u.Path)
-	if m == nil {
-		return 0, nil
-	}
-
-	repo := ghrepo.NewWithHost(m[1], m[2], u.Hostname())
-	issueNumber, _ := strconv.Atoi(m[3])
-	return issueNumber, repo
-}
-
-// Returns the issue number and repo if the issue URL is provided.
-// If only the issue number is provided, returns the number and nil repo.
-func IssueNumberAndRepoFromArg(arg string) (int, ghrepo.Interface, error) {
-	issueNumber, baseRepo := issueMetadataFromURL(arg)
-
-	if issueNumber == 0 {
-		var err error
-		issueNumber, err = strconv.Atoi(strings.TrimPrefix(arg, "#"))
-		if err != nil {
-			return 0, nil, fmt.Errorf("invalid issue format: %q", arg)
-		}
-	}
-
-	return issueNumber, baseRepo, nil
-}
-
-type PartialLoadError struct {
-	error
-}
-
-func findIssueOrPR(httpClient *http.Client, repo ghrepo.Interface, number int, fields []string) (*api.Issue, error) {
+func FindIssueOrPR(httpClient *http.Client, repo ghrepo.Interface, number int, fields []string) (*api.Issue, error) {
 	fieldSet := set.NewStringSet()
 	fieldSet.AddValues(fields)
 	if fieldSet.Contains("stateReason") {
